==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextServiceAvailableEvent.h <==
// public class java.beans.beancontext.BeanContextServiceAvailableEvent

// class file dependencies
// @dep_class 83892d580401761a java_beans_beancontext_BeanContextEvent
// @dep_class 4ff19d55a56c46b3 java_beans_beancontext_BeanContextServiceAvailableEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_beans_beancontext_BeanContextEvent

#include "java/beans/beancontext/BeanContextEvent.h"

#ifndef _JC_java_beans_beancontext_BeanContextServiceAvailableEvent_H_
#define _JC_java_beans_beancontext_BeanContextServiceAvailableEvent_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServices$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_refs	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$refs	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$nonrefs	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object;

typedef const struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vmethods	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtable	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method$_init$9e19381e8ac83443(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);

// Virtual methods
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method$getCurrentServiceSelectors$4de33efaa6737eb4(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *);
extern struct _jc_java_lang_Class$object *_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method$getServiceClass$db02eb3ca356db13(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *);
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method$getSourceAsBeanContextServices$ab85327a997ff09b(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method_info$getCurrentServiceSelectors$4de33efaa6737eb4;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method_info$getServiceClass$db02eb3ca356db13;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method_info$getSourceAsBeanContextServices$ab85327a997ff09b;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vmethods {
	struct _jc_object	*(*getCurrentServiceSelectors$4de33efaa6737eb4)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *);
	struct _jc_java_lang_Class$object	*(*getServiceClass$db02eb3ca356db13)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *);
	struct _jc_object	*(*getSourceAsBeanContextServices$ab85327a997ff09b)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *);
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_beancontext_BeanContextEvent$vmethods	java_beans_beancontext_BeanContextEvent;
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vmethods	java_beans_beancontext_BeanContextServiceAvailableEvent;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_refs {
	struct _jc_java_lang_Class$object	*serviceClass;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$refs {
    _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_refs	java_beans_beancontext_BeanContextServiceAvailableEvent;
    _jc_java_beans_beancontext_BeanContextEvent$sub_refs	java_beans_beancontext_BeanContextEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	java_beans_beancontext_BeanContextEvent;
    _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_nonrefs	java_beans_beancontext_BeanContextServiceAvailableEvent;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object {
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServiceAvailableEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServiceAvailableEvent_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextServiceAvailableEvent.h <==
// public class java.beans.beancontext.BeanContextServiceAvailableEvent

// class file dependencies
// @dep_class 83892d580401761a java_beans_beancontext_BeanContextEvent
// @dep_class 4ff19d55a56c46b3 java_beans_beancontext_BeanContextServiceAvailableEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_beans_beancontext_BeanContextEvent

#include "java/beans/beancontext/BeanContextEvent.h"

#ifndef _JC_java_beans_beancontext_BeanContextServiceAvailableEvent_H_
#define _JC_java_beans_beancontext_BeanContextServiceAvailableEvent_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServices$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_refs	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$refs	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$nonrefs	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object;

typedef const struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vmethods	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtable	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method$_init$9e19381e8ac83443(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method$getCurrentServiceSelectors$4de33efaa6737eb4(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method$getServiceClass$db02eb3ca356db13(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method$getSourceAsBeanContextServices$ab85327a997ff09b(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method_info$getCurrentServiceSelectors$4de33efaa6737eb4;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method_info$getServiceClass$db02eb3ca356db13;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$method_info$getSourceAsBeanContextServices$ab85327a997ff09b;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vmethods {
	struct _jc_object	*(*getCurrentServiceSelectors$4de33efaa6737eb4)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getServiceClass$db02eb3ca356db13)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSourceAsBeanContextServices$ab85327a997ff09b)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_beancontext_BeanContextEvent$vmethods	java_beans_beancontext_BeanContextEvent;
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vmethods	java_beans_beancontext_BeanContextServiceAvailableEvent;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_refs {
	struct _jc_java_lang_Class$object	*serviceClass;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$refs {
    _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_refs	java_beans_beancontext_BeanContextServiceAvailableEvent;
    _jc_java_beans_beancontext_BeanContextEvent$sub_refs	java_beans_beancontext_BeanContextEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	java_beans_beancontext_BeanContextEvent;
    _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$sub_nonrefs	java_beans_beancontext_BeanContextServiceAvailableEvent;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$object {
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServiceAvailableEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$vtype _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServiceAvailableEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServiceAvailableEvent$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServiceAvailableEvent_H_ */
